@@ -1204,6 +1204,7 @@ void op_default_event(op_cpu cpu_type, struct op_default_event_descr * descr)
 		case CPU_WESTMERE:
 		case CPU_SANDYBRIDGE:
 		case CPU_IVYBRIDGE:
+		case CPU_KNIGHTSLANDING:
 		case CPU_MIPS_LOONGSON2:
 		case CPU_FAMILY12H:
 		case CPU_FAMILY14H:
@@ -1212,6 +1213,8 @@ void op_default_event(op_cpu cpu_type, struct op_default_event_descr * descr)
 			descr->name = "CPU_CLK_UNHALTED";
 			break;
 
+		case CPU_GOLDMONT:
+		case CPU_GOLDMONTPLUS:
 		case CPU_SKYLAKE:
 			descr->name = "cpu_clk_unhalted";
 			break;
@@ -1237,6 +1240,7 @@ void op_default_event(op_cpu cpu_type, struct op_default_event_descr * descr)
 		case CPU_ARM_V7_CA7:
 		case CPU_ARM_V7_CA9:
 		case CPU_ARM_V7_CA15:
+		case CPU_ARM_V7_CA17:
 		case CPU_ARM_SCORPION:
 		case CPU_ARM_SCORPIONMP:
 		case CPU_ARM_KRAIT:
@@ -1257,6 +1261,7 @@ void op_default_event(op_cpu cpu_type, struct op_default_event_descr * descr)
 		case CPU_PPC64_POWER7:
 		case CPU_PPC64_ARCH_V1:
 		case CPU_PPC64_POWER8:
+		case CPU_PPC64_POWER9:
 			descr->name = "CYCLES";
 			break;
 
@@ -1306,6 +1311,7 @@ void op_default_event(op_cpu cpu_type, struct op_default_event_descr * descr)
 		case CPU_S390_Z10:
 		case CPU_S390_Z196:
 		case CPU_S390_ZEC12:
+		case CPU_S390_Z13:
 			descr->name = "CPU_CYCLES";
 			descr->count = 4127518;
 			break;
