@@ -59,10 +59,9 @@ static int parse_ulong(char const * str)
 
 
 size_t parse_events(struct parsed_event * parsed_events, size_t max_events,
-                  char const * const * events)
+                  char const * const * events, int check_count)
 {
 	size_t i = 0;
-	int timer_event_found_p = 0;
 
 	while (events[i]) {
 		char const * cp = events[i];
@@ -80,21 +79,19 @@ size_t parse_events(struct parsed_event * parsed_events, size_t max_events,
 			exit(EXIT_FAILURE);
 		}
 
-		if (strcmp(part, TIMER_EVENT_NAME) == 0)
-			timer_event_found_p = 1;
-
 		parsed_events[i].name = part;
 
-		part = next_part(&cp);
+		if (check_count) {
+			part = next_part(&cp);
+			if (!part) {
+				fprintf(stderr, "Invalid count for event %s\n", events[i]);
+				exit(EXIT_FAILURE);
+			}
 
-		if (!part) {
-			fprintf(stderr, "Invalid count for event %s\n", events[i]);
-			exit(EXIT_FAILURE);
+			parsed_events[i].count = parse_ulong(part);
+			free(part);
 		}
 
-		parsed_events[i].count = parse_ulong(part);
-		free(part);
-
 		parsed_events[i].unit_mask = 0;
 		part = next_part(&cp);
 
@@ -126,12 +123,5 @@ size_t parse_events(struct parsed_event * parsed_events, size_t max_events,
 	
 		++i;
 	}
-
-	if (i > 1 && timer_event_found_p) {
-		fprintf(stderr, "TIMER event cannot be used in combination with"
-			" hardware counters.\n");
-		exit(EXIT_FAILURE);
-	}
-
 	return i;
 }
