@@ -73,7 +73,14 @@ static inline void update_trans_last(struct operf_transient * trans)
 
 static inline void clear_trans(struct operf_transient * trans)
 {
-	trans->tgid = ~0U;
+	/* ~0U (-1) could be used by the kernel perf samples
+	 * for the TID/PID of exiting processes. To avoid
+	 * confusing the oprofile logic use ~1U as the
+	 * initialization value for tgid field to avoid
+	 * possibly matching the TID/PID values for exiting
+	 * processes.
+	 */
+	trans->tgid = ~1U;
 	trans->cur_procinfo = NULL;
 }
 
@@ -1333,7 +1340,7 @@ static void _record_module_info(int output_fd, operf_record * pr)
 		mmap.header.type = PERF_RECORD_MMAP;
 		mmap.header.misc = PERF_RECORD_MISC_KERNEL;
 		size = strlen(module_name) + 1;
-		strncpy(mmap.filename, module_name, size);
+		strncpy(mmap.filename, module_name, sizeof(mmap.filename));
 		size = align_64bit(size);
 		mmap.start = start_address;
 		mmap.len = module_size;
