@@ -102,6 +102,8 @@ void profile_spec::set_image_or_lib_name(string const & str)
 void profile_spec::parse_archive_path(string const & str)
 {
 	archive_path = op_realpath(str);
+	/* Need to force session directory default location in the archive */
+	init_op_config_dirs(OP_SESSION_DIR_DEFAULT);
 }
 
 
@@ -385,7 +387,13 @@ bool valid_candidate(string const & base_dir, string const & filename,
 	if (!is_prefix(sub, "/{root}/") && !is_prefix(sub, "/{kern}/"))
 		return false;
 
-	/* When overflows occur in the oprofile kernel driver's sample
+	/** NOTE: This comment and associated code is actually obsolete now,
+	 * since opcontrol and the oprofile kernel driver are no longer
+	 * in use with oprofile (as of release 1.0).  It seems extremely
+	 * unlikely we could encounter the same sort of issue using operf,
+	 * but it doesn't hurt to keep the code to be on the safe side.
+	 *
+	 * When overflows occur in the oprofile kernel driver's sample
 	 * buffers (caused by too high of a sampling rate), it's possible
 	 * for samples to be mis-attributed.  A common scenario is that,
 	 * while profiling process 'abc' running binary 'xzy', the task
@@ -616,9 +624,8 @@ list<string> profile_spec::generate_file_list(bool exclude_dependent,
 
 	if (!found_file) {
 		ostringstream os;
-		os  << "No sample file found: If using opcontrol for profiling,\n"
-		    << "try running 'opcontrol --dump'; otherwise, specify a session containing\n"
-		    << "sample files.\n";
+		os  << "No sample found: Please specify a session containing \n"
+		    << "sample data.\n";
 		throw op_fatal_error(os.str());
 	}
 
