@@ -101,12 +101,6 @@ bool has_separated_thread_info()
 }
 
 
-string get_cpu_num(size_t pclass)
-{
-	return classes.v[pclass].ptemplate.cpu;
-}
-
-
 };  // anonymous namespace
 
 xml_utils::xml_utils(format_output::xml_formatter * xo,
@@ -245,11 +239,11 @@ void xml_utils::add_option(tag_t tag, bool value)
 void xml_utils::output_xml_header(string const & command_options,
                        string const & cpu_info, string const & events)
 {
-	// the integer portion indicates the schema version and should change
+	// The integer portion indicates the schema version and should change
 	// both here and in the schema file when major changes are made to
-	// the schema.  changes to opreport, or minor changes to the schema
+	// the schema.  Changes to opreport, or minor changes to the schema
 	// can be indicated by changes to the fraction part.
-	string const schema_version = "3.0";
+	string const schema_version = "3.1";
 
 	// This is the XML version, not schema version.
 	string const xml_header = "<?xml version=\"1.0\" ?>";
@@ -683,12 +677,14 @@ summarize_binaries(extra_images const & extra_found_images)
 			current_binary = binaries_root.add_binary(binary, it);
 			current_binary_name = binary;
 		}
-
-		current_binary->add_module_symbol(module, binary, it);
+		// To silence coverity, check current_binary !=NULL
+		if (current_binary)
+			current_binary->add_module_symbol(module, binary, it);
 	}
 
 	// close out last binary and module
-	current_binary->close_binary(symbols_end);
+	if (current_binary)
+		current_binary->close_binary(symbols_end);
 }
 
 
